@@ -23,6 +23,7 @@ logger = getLogger(__name__)
 
 
 base_params = {
+    "averaging": "off",
     "datekeyhtml": 1,
     "ls": 85.3,
     "localtime": 0.0,  # noqa
@@ -134,7 +135,6 @@ def fetch_data(outdir: Union[Path, str] = ".", get_data: bool = True, get_img: b
     r = requests.get(url, params=p)
     if "Ooops!" in r.text:
         raise FetchingError(f"Failed to download, server said {r.text}")
-    print(r, r.text)
     soup = BeautifulSoup(r.text, features="html.parser")
     if isinstance(outdir, str):
         outdir = Path(outdir).expanduser().resolve()
